@@ -7,8 +7,7 @@ using FiniteDifferences
     # `central_fdm(5, 1)` is not type-inferrable, so only check inferrability
     # with user-specified method
     backends = [
-        AD.FiniteDifferencesBackend(),
-        @inferred(AD.FiniteDifferencesBackend(method)),
+        AD.FiniteDifferencesBackend(), @inferred(AD.FiniteDifferencesBackend(method))
     ]
     @test backends[2].method === method
 
@@ -22,6 +21,9 @@ using FiniteDifferences
         @testset "Jacobian" begin
             test_jacobians(backend)
         end
+        @testset "Second derivative" begin
+            test_second_derivatives(backend)
+        end
         @testset "Hessian" begin
             test_hessians(backend)
         end
